==> kwordquiz-17.04.1.tar.xz: kwordquiz-17.04.1/src/kwqtutorflashcard.h <==
/***************************************************************************
                             kwqtutorflashcard.h
                             -------------------

    copyright            : (C) 2010 by Peter Hedlund
    email                : peter.hedlund@kdemail.net

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KWQTUTORFLASHCARD_H
#define KWQTUTORFLASHCARD_H

#include <QLabel>
#include <QVBoxLayout>
#include <QCloseEvent>

#include "kwqcardview.h"

class KWQTutorFlashCard : public QWidget
{
  Q_OBJECT

  public:
    explicit KWQTutorFlashCard(QWidget* parent = 0);
    void init();
    /* reimplemented func to save flashcard geometry before closing */
    void closeEvent (QCloseEvent* event);
    void setText(const QString &);

  private:
    QVBoxLayout* m_cardLayout;
    KWQCardView* m_card;
    QLabel* m_label;
    QString m_text;
};

#endif // KWQTUTORFLASHCARD_H

==> kwordquiz-18.12.0.tar.xz: kwordquiz-18.12.0/src/kwqtutorflashcard.h <==
/***************************************************************************
                             kwqtutorflashcard.h
                             -------------------

    copyright            : (C) 2010 by Peter Hedlund
    email                : peter.hedlund@kdemail.net

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KWQTUTORFLASHCARD_H
#define KWQTUTORFLASHCARD_H

#include <QCloseEvent>
#include <QLabel>
#include <QVBoxLayout>

#include "kwqcardview.h"

class KWQTutorFlashCard : public QWidget
{
  Q_OBJECT

  public:
    explicit KWQTutorFlashCard(QWidget* parent = 0);
    void init();
    /* reimplemented func to save flashcard geometry before closing */
    void closeEvent (QCloseEvent* event) Q_DECL_OVERRIDE;
    void setText(const QString &);

  private:
    QVBoxLayout* m_cardLayout;
    KWQCardView* m_card;
    QLabel* m_label;
    QString m_text;
};

#endif // KWQTUTORFLASHCARD_H
